@@ -11,25 +11,26 @@
 #include "loader.h"
 char* loadfile(int elems, const char* fname)
 {
-    int fd;
-    char *addr;
+    int fd = 0;
+    char *addr = 0;
     fd = open(fname, O_RDONLY);
-
+printf("Attempting to mmap %d elements from %s\n", (elems - 1) * 4, fname);
     // // void *mmap(void *addr, size_t length, int prot, int flags,
     // //            int fd, off_t offset);
-    int optmap[elems];
+addr = malloc(elems * 4);
     off_t  pa_offset = 0;
-
-    addr = mmap(NULL,
-                elems* 4, 
-                PROT_READ, 
-                MAP_PRIVATE, 
-                fd, 
-                pa_offset);
+    int r = read(fd, addr, elems * 4);
+    printf("loaded %d bytes from optical map for sa purposes\n", r);
+    // addr = mmap(NULL,
+    //                 (elems - 1)* 4, 
+    //             PROT_READ, 
+    //             MAP_PRIVATE, 
+    //             fd, 
+    //             pa_offset);
     // if (fread(&optmap, 4, fm_index.size(), (FILE*) fd) != fm_index.size()) {
     //     std::cerr << "Failed to read entire optical map" << std::endl;
     // }
 
-
-
+//    printf("loaded file at %d\n", (unsigned long long)addr);
+    return addr;
 }
